@@ -92,6 +92,9 @@ do {
   }
 } while( $done && @ARGV);
 
+my $requestName = 'findItemsAdvanced';
+$requestName = 'findCompletedItems' if defined $completed;
+
 my $query = join(" ", @ARGV );
 
 # use new eBay API
@@ -103,6 +106,7 @@ my $request =
                   EntriesPerPage => 399,
                   PageNumber => 1,
                  },
+   #sortOrder => 'StartTimeNewest',
   };
 
 $request->{keywords} = $query if $query;
@@ -134,8 +138,7 @@ if( defined $distance && defined $zip ) {
 addItemFilter( $request, 'MinPrice', $minprice ) if $minprice;
 addItemFilter( $request, 'MaxPrice', $minprice ) if $maxprice;
 
-$request->{categoryID} = $category if(defined $category); 
-$request->{SearchType} = 'Completed' if(defined $completed); 
+$request->{categoryID} = $category if(defined $category);
 
 $request->{ItemTypeFilter} = 'AllItemTypes' if $all;
 
@@ -151,7 +154,7 @@ if( $currency ) {
 my $result;
 my $items;
 
-$result = $eBay->submitFindingRequest( "findItemsAdvanced", $request );
+$result = $eBay->submitPaginatedFindingRequest( $requestName, $request );
 
 print Dumper( $request ) if $detail;
 print Dumper( $result ) if $detail;
@@ -185,17 +188,19 @@ if( ref $result ) {
     $items = [$items] if( ref $items eq 'HASH' );
     foreach my $item (@$items) {
 
+      next unless defined $item;
+
       # Apply extra filters
       next if $nofeatured && ref $item->{ListingEnhancement};
       next if $nobins     && $item->{BuyItNowPrice};
-      
+
       print "$item->{itemId} ";
-      
+
       my $endtime = $item->{listingInfo}->{endTime};
       $endtime =~ s/T/ /;
       $endtime =~ s/\.\d\d\d//;
       $endtime =~ s/Z/GMT/;
-      
+
       ############################################################
       # now figure out ending time in the LOCAL timezone
       # (not GMT and not necessarily California time)
